"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fast_xml_parser_1 = require("fast-xml-parser");
const stream_1 = require("stream");
const baseMetadataTransformer_1 = require("./baseMetadataTransformer");
const convertTransaction_1 = require("../convertTransaction");
const constants_1 = require("../../utils/constants");
const errors_1 = require("../../errors");
const path_1 = require("path");
class DecomposedMetadataTransformer extends baseMetadataTransformer_1.BaseMetadataTransformer {
    constructor(component, convertTransaction) {
        super(component, convertTransaction);
        this.convertTransaction.addFinalizer(convertTransaction_1.RecompositionFinalizer);
    }
    toMetadataFormat() {
        if (this.component.parent) {
            const { state } = this.convertTransaction;
            const { fullName: parentName } = this.component.parent;
            if (!state.recompose[parentName]) {
                state.recompose[parentName] = {
                    component: this.component.parent,
                    children: [],
                };
            }
            state.recompose[parentName].children.push(this.component);
            // noop since the finalizer will push the writes to the component writer
            return { component: this.component, writeInfos: [] };
        }
        const recomposedXmlObj = DecomposedMetadataTransformer.recompose(this.component.getChildren(), this.component.parseXml());
        return DecomposedMetadataTransformer.createWriterFormat(this.component, recomposedXmlObj);
    }
    toSourceFormat() {
        throw new errors_1.LibraryError('error_convert_not_implemented', ['source', this.component.type.name]);
    }
    static recompose(children, baseXmlObj = {}) {
        for (const child of children) {
            const { directoryName: groupNode } = child.type;
            const { name: parentName } = child.parent.type;
            const childContents = child.parseXml()[child.type.name];
            if (!baseXmlObj[parentName]) {
                baseXmlObj[parentName] = { '@_xmlns': constants_1.XML_NS };
            }
            else if (!baseXmlObj[parentName][constants_1.XML_NS_KEY]) {
                baseXmlObj[parentName][constants_1.XML_NS_KEY] = constants_1.XML_NS;
            }
            if (!baseXmlObj[parentName][groupNode]) {
                baseXmlObj[parentName][groupNode] = [];
            }
            baseXmlObj[parentName][groupNode].push(childContents);
        }
        return baseXmlObj;
    }
    static createWriterFormat(trigger, xmlJson) {
        const js2Xml = new fast_xml_parser_1.j2xParser({ format: true, indentBy: '  ', ignoreAttributes: false });
        const source = new stream_1.Readable();
        source.push(constants_1.XML_DECL.concat(js2Xml.parse(xmlJson)));
        source.push(null);
        return {
            component: trigger,
            writeInfos: [
                {
                    relativeDestination: path_1.join(trigger.type.directoryName, `${trigger.fullName}.${trigger.type.suffix}`),
                    source,
                },
            ],
        };
    }
}
exports.DecomposedMetadataTransformer = DecomposedMetadataTransformer;
//# sourceMappingURL=decomposedMetadataTransformer.js.map