"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const baseMetadataTransformer_1 = require("./baseMetadataTransformer");
const archiver_1 = require("archiver");
const path_1 = require("path");
const utils_1 = require("../../utils");
const fs_1 = require("fs");
const errors_1 = require("../../errors");
const constants_1 = require("../../utils/constants");
class StaticResourceMetadataTransformer extends baseMetadataTransformer_1.BaseMetadataTransformer {
    toMetadataFormat() {
        let contentSource;
        const { content, type, xml } = this.component;
        const writerFormat = {
            component: this.component,
            writeInfos: [],
        };
        if (this.componentIsExpandedArchive()) {
            const zip = archiver_1.create('zip', { zlib: { level: 3 } });
            zip.directory(content, false);
            zip.finalize();
            contentSource = zip;
        }
        else {
            contentSource = fs_1.createReadStream(content);
        }
        writerFormat.writeInfos.push({
            source: contentSource,
            relativeDestination: path_1.join(type.directoryName, `${utils_1.baseName(content)}.${type.suffix}`),
        }, {
            source: fs_1.createReadStream(xml),
            relativeDestination: path_1.join(type.directoryName, path_1.basename(xml)),
        });
        return writerFormat;
    }
    toSourceFormat() {
        throw new errors_1.LibraryError('error_convert_not_implemented', ['source', this.component.type.name]);
    }
    componentIsExpandedArchive() {
        const { content, tree } = this.component;
        if (tree.isDirectory(content)) {
            const contentType = this.component.parseXml().StaticResource
                .contentType;
            if (constants_1.ARCHIVE_MIME_TYPES.has(contentType)) {
                return true;
            }
            throw new errors_1.LibraryError('error_static_resource_expected_archive_type', [
                contentType,
                this.component.name,
            ]);
        }
        return false;
    }
}
exports.StaticResourceMetadataTransformer = StaticResourceMetadataTransformer;
//# sourceMappingURL=staticResourceMetadataTransformer.js.map